==> azureus_2.2.0.2.orig.tar.gz: azureus-2.2.0.2.orig/com/aelitis/azureus/core/proxy/socks/AESocksProxyFactory.java <==
/*
 * Created on 08-Dec-2004
 * Created by Paul Gardner
 * Copyright (C) 2004 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SARL au capital de 30,000 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package com.aelitis.azureus.core.proxy.socks;

/**
 * @author parg
 *
 */

import com.aelitis.azureus.core.proxy.AEProxyException;
import com.aelitis.azureus.core.proxy.socks.impl.*;

public class 
AESocksProxyFactory 
{
	public static AESocksProxy
	create(
		int			port,
		long		connect_timeout,
		long		read_timeout )
	
		throws AEProxyException
	{
		return( create( port, 
						connect_timeout,
						read_timeout,
						new AESocksProxyPlugableConnectionFactory()
						{
							public AESocksProxyPlugableConnection
							create(
								AESocksProxyConnection	connection )
							{
								return( new AESocksProxyPlugableConnectionDefault( connection ));
							}
						}));
	}
	
	public static AESocksProxy
	create(
		int										port,
		long									connect_timeout,
		long									read_timeout,
		AESocksProxyPlugableConnectionFactory	connection_factory )
	
			throws AEProxyException
	{
		return( new AESocksProxyImpl( port, connect_timeout, read_timeout, connection_factory ));
	}
}

==> azureus_4.3.0.6.orig.tar.gz: azureus-4.3.0.6/com/aelitis/azureus/core/proxy/socks/AESocksProxyFactory.java <==
/*
 * Created on 08-Dec-2004
 * Created by Paul Gardner
 * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 46,603.30 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package com.aelitis.azureus.core.proxy.socks;

/**
 * @author parg
 *
 */

import com.aelitis.azureus.core.proxy.AEProxyException;
import com.aelitis.azureus.core.proxy.socks.impl.*;

public class 
AESocksProxyFactory 
{
	public static AESocksProxy
	create(
		int			port,
		long		connect_timeout,
		long		read_timeout )
	
		throws AEProxyException
	{
		return( create( port, 
						connect_timeout,
						read_timeout,
						new AESocksProxyPlugableConnectionFactory()
						{
							public AESocksProxyPlugableConnection
							create(
								AESocksProxyConnection	connection )
							{
								return( new AESocksProxyPlugableConnectionDefault( connection ));
							}
						}));
	}
	
	public static AESocksProxy
	create(
		int										port,
		long									connect_timeout,
		long									read_timeout,
		AESocksProxyPlugableConnectionFactory	connection_factory )
	
			throws AEProxyException
	{
		return( new AESocksProxyImpl( port, connect_timeout, read_timeout, connection_factory ));
	}
	
	public static void
	main(
		String[]	args )
	{
		try{
			AESocksProxy	proxy = create( 1080, 30*1000, 30*1000 );
			
			Thread.sleep(24*60*60*10000);
			
		}catch( Throwable e ){
			
			e.printStackTrace();
		}
	}
}
